Index: main/asterisk.c
===================================================================
--- main/asterisk.c	(revision 240324)
+++ main/asterisk.c	(working copy)
@@ -2512,7 +2512,8 @@
 static int ast_el_initialize(void)
 {
 	HistEvent ev;
-	char *editor = getenv("AST_EDITOR");
+	char filename[80];
+	char *tenv;
 
 	if (el != NULL)
 		el_end(el);
@@ -2522,8 +2523,10 @@
 	el = el_init("asterisk", stdin, stdout, stderr);
 	el_set(el, EL_PROMPT, cli_prompt);
 
-	el_set(el, EL_EDITMODE, 1);		
-	el_set(el, EL_EDITOR, editor ? editor : "emacs");		
+	el_set(el, EL_EDITMODE, 1);
+
+	tenv = getenv("AST_EDITOR");
+	el_set(el, EL_EDITOR, tenv ? tenv : "emacs");
 	el_hist = history_init();
 	if (!el || !el_hist)
 		return -1;
@@ -2540,7 +2543,28 @@
 	el_set(el, EL_BIND, "?", "ed-complete", NULL);
 	/* Bind ^D to redisplay */
 	el_set(el, EL_BIND, "^D", "ed-redisplay", NULL);
+	/* Bind Delete to delete char left */
+	el_set(el, EL_BIND, "\\e[3~", "ed-delete-next-char", NULL);
+	/* Bind Home and End to move to line start and end */
+	el_set(el, EL_BIND, "\\e[1~", "ed-move-to-beg", NULL);
+	el_set(el, EL_BIND, "\\e[4~", "ed-move-to-end", NULL);
+	/* Bind C-left and C-right to move by word (not all terminals) */
+	el_set(el, EL_BIND, "\\eOC", "vi-next-space-word", NULL);
+	el_set(el, EL_BIND, "\\eOD", "vi-prev-space-word", NULL);
 
+	/* Allow ~/.editrc or a file specified by EDITRC env to override */
+	/* Not using el_source(el, NULL) as that does not work on non-BSD systems! */
+	tenv = getenv("EDITRC");
+	if (tenv)
+		el_source(el, tenv);
+	else {
+		tenv = getenv("HOME");
+		if (tenv) {
+			snprintf(filename, sizeof(filename), "%s/.editrc", tenv);
+			el_source(el, filename);
+		}
+	}
+
 	return 0;
 }
 
